# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.shopify_amz_product_formatter import ShopifyAmzProductFormatter
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config, get_product_service


@click.command('Format Amazon product from Spapi.')
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Amazon marketplace.')
@click.option('-l', '--location_id', required=True, type=str, help='Location ID.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
@click.argument('asins_path')
def format_products(asins_path, output_path, location_id, marketplace='us'):
  if not asins_path:
    return

  asins_path = os.path.abspath(os.path.expanduser(asins_path))
  if not os.path.isfile(asins_path):
    return

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  filter_cond = get_amz_offer_filter_config()
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 12
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.amz_{}'.format(marketplace), dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  product_service = get_product_service()

  formatter = ShopifyAmzProductFormatter(marketplace, product_service, offer_service, price_calculator)
  asins = []
  batch_size = 500
  with open(output_path, 'w+', encoding='utf-8', errors='ignore') as output_fh:
    with open(asins_path, encoding='utf-8', errors='ignore') as fh:
      for line in fh:
        s = line.strip()
        if not s:
          continue

        asins.append(s)
        if len(asins) < batch_size:
          continue

        records = []
        prods = formatter.format_products(asins)
        for prod in prods.values():
          if not prod:
            continue

          prod['location_id'] = location_id
          records.append(json.dumps(prod))

        output_fh.write("\n".join(records))
        output_fh.write("\n")

        asins = []

      if asins:
        records = []
        prods = formatter.format_products(asins)
        for prod in prods.values():
          if not prod or not prod['quantity']:
            continue

          prod['location_id'] = location_id
          records.append(json.dumps(prod))

        output_fh.write("\n".join(records))
        output_fh.write("\n")

        asins = []



if __name__ == "__main__":
  format_products()
