# -*- coding: utf-8 -*-

import datetime

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.shopify_amz_custom_label_updater import ShopifyAmzCustomLabelUpdater
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config


@click.command('Update Shopify Amazon products Google product custom label')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-m', '--marketplace', type=str, default='us')
def update_custom_label(store_code, marketplace='us'):
  init_db()

  filter_cond = get_amz_offer_filter_config()
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 0
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.amz_{}'.format(marketplace), dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  updater = ShopifyAmzCustomLabelUpdater(store_code, marketplace, offer_service, price_calculator)
  updater.run()


if __name__ == "__main__":
  update_custom_label()
