# -*- coding: utf-8 -*-

import datetime
import json
import time
import re

import click
import dateparser

from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.shopify_ebay_custom_label_updater import ShopifyEbayCustomLabelUpdater

from em_celery import logger, get_config, init_db, get_product_service


@click.command('Shopify ebay google product custom label update.')
@click.option('-s', '--store_code', type=str, required=True)
@click.option('-m', '--marketplace', type=str, default='us')
@click.option('-t', '--ttl', type=int, default=7)
def update_custom_label(store_code, marketplace='us', ttl=7):
  init_db()
  product_service = get_product_service()

  price_rules = {
    'roi': 0.3,
    'ad_cost': 5,
    'transfer_cost': 1
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.ebay_{}'.format(marketplace), dict())
  price_rules.update(price_rules_cfg)
  price_calculator = PriceCalculator(price_rules)

  updater = ShopifyEbayCustomLabelUpdater(store_code, product_service, price_calculator, marketplace, ttl)
  updater.run()

if __name__ == '__main__':
  update_custom_label()
