# -*- coding: utf-8 -*-

import datetime
import json

import click
import shopify
import pyactiveresource
import shopify_python_api_patcher
from shopify_python_api_patcher.utils import get_current_release

from em_celery import logger, init_db, get_config
from em_tasks.store.store_util import StoreUtil
from em_tasks.utils.shopify_nofraud_scanner import ShopifyNofraudScanner
from em_tasks.store.models import *


@click.command('Scanner Shopify investigate orders by Nofraud')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-d', '--days', type=int, default=7, help='Sync how many days order, default is 7.')
def scan_orders(store_code, days=7):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  credential = json.loads(store.api_credential)
  release = get_current_release()
  app_token = credential['token']
  shop_url = "{}.myshopify.com".format(credential['name'])

  session = shopify.Session(shop_url, release, app_token)
  shopify.ShopifyResource.activate_session(session)

  cfg = get_config()
  if 'nofraud' not in cfg:
    logger.error('[NofraudConfigurationMissing] Exit')
    return

  nofraud_cfg = cfg['nofraud']

  scanner = ShopifyNofraudScanner(nofraud_cfg['api_token'], days)
  scanner.run()


if __name__ == "__main__":
  scan_orders()
