# -*- coding: utf-8 -*-

import json

import click

from em_tasks.store.store_util import StoreUtil
from em_tasks.tools.shopify_products_indexer import ShopifyProductsIndexer
from em_tasks.store.models import *

from em_celery import logger, init_db, get_product_service


@click.command('Index shopify products.')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
def index_products(store_code):
  init_db()

  store = StoreUtil.get_store_by_code(store_code)
  if not store:
    logger.warning('[StoreNotFound] %s', store_code)
    return

  product_service = get_product_service()
  indexer = ShopifyProductsIndexer(product_service)
  indexer.run()


if __name__ == "__main__":
  index_products()
